@@ -10,5 +10,5 @@ pub(super) mod gate;
 pub(super) mod huobi;
 pub(super) mod kucoin;
 pub(super) mod mxc;
-pub(super) mod okex;
+pub(super) mod okx;
 pub(super) mod zbg;
